@@ -2,10 +2,11 @@
 
 __author__ = """Matthew Andres Moreno"""
 __email__ = "m.more500@gmail.com"
-__version__ = "1.5.0"
+__version__ = "1.6.1"
 
 from . import (
     _auxiliary_lib,
+    frozen_instrumentation,
     genome_instrumentation,
     juxtaposition,
     phylogenetic_inference,
@@ -17,6 +18,7 @@ from . import (
 
 __all__ = [
     "_auxiliary_lib",
+    "frozen_instrumentation",
     "genome_instrumentation",
     "juxtaposition",
     "phylogenetic_inference",
