@@ -1,14 +1,17 @@
 import typing
 
-from ..genome_instrumentation import HereditaryStratigraphicColumn
+from .._auxiliary_lib import HereditaryStratigraphicArtifact
+from ._calc_min_implausible_spurious_consecutive_differentia_collisions_between import (
+    calc_min_implausible_spurious_consecutive_differentia_collisions_between,
+)
 from ._calc_ranks_since_first_retained_disparity_with import (
     calc_ranks_since_first_retained_disparity_with,
 )
 
 
 def calc_definitive_min_ranks_since_first_retained_disparity_with(
-    focal: HereditaryStratigraphicColumn,
-    other: HereditaryStratigraphicColumn,
+    focal: HereditaryStratigraphicArtifact,
+    other: HereditaryStratigraphicArtifact,
 ) -> typing.Optional[int]:
     """Determine a hard, exclusive lower bound on generations since MRCA.
 
@@ -26,7 +29,9 @@ def calc_definitive_min_ranks_since_first_retained_disparity_with(
         == other.GetStratumDifferentiaBitWidth()
     )
     assert (
-        focal.CalcMinImplausibleSpuriousConsecutiveDifferentiaCollisions(
+        calc_min_implausible_spurious_consecutive_differentia_collisions_between(
+            focal,
+            other,
             significance_level=1.0 - confidence_level,
         )
         == 1
