@@ -1,7 +1,7 @@
 import operator
 import typing
 
-from ...genome_instrumentation import HereditaryStratigraphicColumn
+from ..._auxiliary_lib import HereditaryStratigraphicArtifact
 from ._calc_rank_of_earliest_detectable_mrca_between import (
     calc_rank_of_earliest_detectable_mrca_between,
 )
@@ -9,8 +9,9 @@ from ._calc_rank_of_mrca_bounds_between import calc_rank_of_mrca_bounds_between
 
 
 def calc_rank_of_mrca_uncertainty_between(
-    first: HereditaryStratigraphicColumn,
-    second: HereditaryStratigraphicColumn,
+    first: HereditaryStratigraphicArtifact,
+    second: HereditaryStratigraphicArtifact,
+    prior: str,
     confidence_level: float = 0.95,
 ) -> typing.Optional[int]:
     """How wide is the estimate window for generation of MRCA?
@@ -42,6 +43,9 @@ def calc_rank_of_mrca_uncertainty_between(
     bounds = calc_rank_of_mrca_bounds_between(
         first,
         second,
+        prior=prior,
         confidence_level=confidence_level,
     )
-    return 0 if bounds is None else abs(operator.sub(*bounds)) - 1
+    # must coerce to int because
+    # numpy unsigned types wraparound when subtracting larger from smaller
+    return 0 if bounds is None else abs(operator.sub(*map(int, bounds))) - 1
