@@ -1,14 +1,13 @@
-import typing
-
-from ...genome_instrumentation import HereditaryStratigraphicColumn
+from ..._auxiliary_lib import HereditaryStratigraphicArtifact
 from ._calc_rank_of_mrca_bounds_provided_confidence_level import (
     calc_rank_of_mrca_bounds_provided_confidence_level,
 )
 
 
 def calc_ranks_since_mrca_bounds_provided_confidence_level(
-    focal: HereditaryStratigraphicColumn,
-    other: typing.Optional[HereditaryStratigraphicColumn] = None,
+    focal: HereditaryStratigraphicArtifact,
+    other: HereditaryStratigraphicArtifact,
+    prior: str,
     requested_confidence_level: float = 0.95,
 ) -> float:
     """Calculate provided confidence for a MRCA generation estimate.
@@ -21,5 +20,6 @@ def calc_ranks_since_mrca_bounds_provided_confidence_level(
     return calc_rank_of_mrca_bounds_provided_confidence_level(
         focal,
         other,
+        prior,
         requested_confidence_level,
     )
