@@ -1,6 +1,8 @@
 """Functions to infer phylogenetic history among a population of extant hstrat
 columns."""
 
+from ._build_distance_matrix_biopython import build_distance_matrix_biopython
+from ._build_distance_matrix_numpy import build_distance_matrix_numpy
 from ._calc_rank_of_earliest_detectable_mrca_among import (
     calc_rank_of_earliest_detectable_mrca_among,
 )
@@ -14,6 +16,8 @@ from ._does_definitively_share_no_common_ancestor import (
 from ._does_share_any_common_ancestor import does_share_any_common_ancestor
 
 __all__ = [
+    "build_distance_matrix_biopython",
+    "build_distance_matrix_numpy",
     "calc_rank_of_earliest_detectable_mrca_among",
     "calc_rank_of_mrca_bounds_among",
     "calc_rank_of_mrca_uncertainty_among",
