@@ -8,15 +8,22 @@ from ._col_to_records import col_to_records
 
 def pop_to_records(
     columns: typing.Iterable[HereditaryStratigraphicColumn],
+    progress_wrap: typing.Callable = lambda x: x,
 ) -> typing.Dict:
     """Serialize a sequence of `HereditaryStratigraphicColumn`s to a dict
     composed of builtin types.
 
-    All `HereditaryStratigraphicColumn`s must share identical `policy`,
-    `policy_algo`, `policy_spec`, and `differentia_bit_width`. For efficiency,
-    these records are recorded once for all columns.
+    Parameters
+    ----------
+    columns : iterable of HereditaryStratigraphicColumn
+        Data to serialize.
+    progress_wrap : Callable, default identity function
+        Wrapper applied around generation iterator and row generator for final
+        phylogeny compilation process.
+
+        Pass tqdm or equivalent to display progress bars.
     """
-    col_records = [col_to_records(column) for column in columns]
+    col_records = [col_to_records(column) for column in progress_wrap(columns)]
 
     res = {}
     for common_field in (
