@@ -5,7 +5,7 @@ from ._calc_target_recency import calc_target_recency
 def calc_rank_sep(
     degree: int,
     interspersal: int,
-    pow: int,
+    pow_: int,
     num_strata_deposited: int,
 ) -> int:
     """How far apart should ranks retained to cover the `pow`th target recency
@@ -13,7 +13,7 @@ def calc_rank_sep(
 
     Will be a power of 2 monotonically increasing with `num_strata_deposited`.
     """
-    target_recency = calc_target_recency(degree, pow, num_strata_deposited)
+    target_recency = calc_target_recency(degree, pow_, num_strata_deposited)
     # spacing between retained ranks
     target_retained_ranks_sep = max(
         target_recency / interspersal,
