@@ -7,7 +7,7 @@ from ._calc_common_ratio import calc_common_ratio
 
 def calc_target_recency(
     degree: int,
-    pow: int,
+    pow_: int,
     num_strata_deposited: int,
 ) -> typing.Union[float, mp.mpf]:
     """ "What should the target recency of the `pow`'th exponentially
@@ -17,7 +17,7 @@ def calc_target_recency(
     """
     common_ratio = calc_common_ratio(degree, num_strata_deposited)
     try:
-        res = common_ratio**pow
+        res = common_ratio**pow_
     except OverflowError:
-        res = mp.mpf(common_ratio) ** pow
+        res = mp.mpf(common_ratio) ** pow_
     return res
