@@ -1,4 +1,4 @@
-from copy import deepcopy
+from copy import copy, deepcopy
 import itertools as it
 import pickle
 import random
@@ -102,7 +102,8 @@ def test_Clone3(retention_policy, ordered_store):
     )
     population = [column.Clone() for __ in range(3)]
 
-    for generation in range(100):
+    for _generation in range(100):
+        _ = _generation
 
         for f, s in it.combinations(population, 2):
             assert not f.HasDiscardedStrata()
@@ -148,7 +149,8 @@ def test_Clone4(retention_policy, ordered_store):
     )
     population = [column.Clone() for __ in range(3)]
 
-    for generation in range(100):
+    for _generation in range(100):
+        _ = _generation
 
         for f, s in it.combinations(population, 2):
             assert not f.HasDiscardedStrata()
@@ -339,7 +341,9 @@ def test_annotation(retention_policy, ordered_store):
 
     for generation in range(100):
         for f, s in it.combinations(population, 2):
-            lb, ub = hstrat.calc_rank_of_mrca_bounds_between(f, s)
+            lb, ub = hstrat.calc_rank_of_mrca_bounds_between(
+                f, s, prior="arbitrary"
+            )
             assert (
                 lb
                 <= hstrat.get_last_common_stratum_between(f, s).GetAnnotation()
@@ -438,17 +442,43 @@ def test_maximal_retention_policy():
         assert second.GetNumStrataRetained() == gen + 1
         assert third.GetNumStrataRetained() == 1
 
-        assert hstrat.calc_rank_of_mrca_uncertainty_between(first, second) == 0
-        assert hstrat.calc_rank_of_mrca_uncertainty_between(first, third) == 0
+        assert (
+            hstrat.calc_rank_of_mrca_uncertainty_between(
+                first, second, prior="arbitrary"
+            )
+            == 0
+        )
+        assert (
+            hstrat.calc_rank_of_mrca_uncertainty_between(
+                first, third, prior="arbitrary"
+            )
+            == 0
+        )
 
         assert (
-            hstrat.calc_ranks_since_mrca_uncertainty_with(first, second) == 0
+            hstrat.calc_ranks_since_mrca_uncertainty_with(
+                first, second, prior="arbitrary"
+            )
+            == 0
         )
         assert (
-            hstrat.calc_ranks_since_mrca_uncertainty_with(second, first) == 0
+            hstrat.calc_ranks_since_mrca_uncertainty_with(
+                second, first, prior="arbitrary"
+            )
+            == 0
+        )
+        assert (
+            hstrat.calc_ranks_since_mrca_uncertainty_with(
+                first, third, prior="arbitrary"
+            )
+            == 0
+        )
+        assert (
+            hstrat.calc_ranks_since_mrca_uncertainty_with(
+                third, first, prior="arbitrary"
+            )
+            == 0
         )
-        assert hstrat.calc_ranks_since_mrca_uncertainty_with(first, third) == 0
-        assert hstrat.calc_ranks_since_mrca_uncertainty_with(third, first) == 0
 
         first.DepositStratum()
         second.DepositStratum()
@@ -468,18 +498,37 @@ def test_minimal_retention_policy():
         assert third.GetNumStrataRetained() == 1
 
         assert hstrat.calc_rank_of_mrca_uncertainty_between(
-            first, second
+            first, second, prior="arbitrary"
         ) == max(0, gen - 1)
-        assert hstrat.calc_rank_of_mrca_uncertainty_between(first, third) == 0
+        assert (
+            hstrat.calc_rank_of_mrca_uncertainty_between(
+                first, third, prior="arbitrary"
+            )
+            == 0
+        )
 
         assert hstrat.calc_ranks_since_mrca_uncertainty_with(
-            first, second
+            first,
+            second,
+            prior="arbitrary",
         ) == max(0, gen - 1)
         assert hstrat.calc_ranks_since_mrca_uncertainty_with(
-            second, first
+            second,
+            first,
+            prior="arbitrary",
         ) == max(0, gen - 1)
-        assert hstrat.calc_ranks_since_mrca_uncertainty_with(first, third) == 0
-        assert hstrat.calc_ranks_since_mrca_uncertainty_with(third, first) == 0
+        assert (
+            hstrat.calc_ranks_since_mrca_uncertainty_with(
+                first, third, prior="arbitrary"
+            )
+            == 0
+        )
+        assert (
+            hstrat.calc_ranks_since_mrca_uncertainty_with(
+                third, first, prior="arbitrary"
+            )
+            == 0
+        )
 
         first.DepositStratum()
         second.DepositStratum()
@@ -601,6 +650,35 @@ def test_IterRetainedStrata(retention_policy, ordered_store):
         ]
 
 
+@pytest.mark.parametrize(
+    "retention_policy",
+    [
+        hstrat.perfect_resolution_algo.Policy(),
+        hstrat.nominal_resolution_algo.Policy(),
+        hstrat.fixed_resolution_algo.Policy(fixed_resolution=10),
+    ],
+)
+@pytest.mark.parametrize(
+    "ordered_store",
+    [
+        hstrat.HereditaryStratumOrderedStoreDict,
+        hstrat.HereditaryStratumOrderedStoreList,
+        hstrat.HereditaryStratumOrderedStoreTree,
+    ],
+)
+def test_IterRetainedDifferentia(retention_policy, ordered_store):
+    column = hstrat.HereditaryStratigraphicColumn(
+        stratum_ordered_store=ordered_store,
+        stratum_retention_policy=retention_policy,
+    )
+    for __ in range(20):
+        column.DepositStratum()
+        assert [*column.IterRetainedDifferentia()] == [
+            column.GetStratumAtColumnIndex(index).GetDifferentia()
+            for index in range(column.GetNumStrataRetained())
+        ]
+
+
 def test_GetColumnIndexOfRank():
     assert (
         hstrat.HereditaryStratigraphicColumn().GetColumnIndexOfRank(1) is None
@@ -752,6 +830,47 @@ def test_DepositStrata_several(retention_policy, ordered_store):
         assert c1.GetNumStrataDeposited() == c2.GetNumStrataDeposited()
 
 
+@pytest.mark.parametrize(
+    "retention_policy",
+    [
+        hstrat.perfect_resolution_algo.Policy(),
+        hstrat.nominal_resolution_algo.Policy(),
+        hstrat.fixed_resolution_algo.Policy(fixed_resolution=10),
+        hstrat.recency_proportional_resolution_algo.Policy(
+            recency_proportional_resolution=2
+        ),
+    ],
+)
+@pytest.mark.parametrize(
+    "ordered_store",
+    [
+        hstrat.HereditaryStratumOrderedStoreDict,
+        hstrat.HereditaryStratumOrderedStoreList,
+        hstrat.HereditaryStratumOrderedStoreTree,
+    ],
+)
+def test_IterRankDifferentiaZip(retention_policy, ordered_store):
+    c1 = hstrat.HereditaryStratigraphicColumn(
+        stratum_ordered_store=ordered_store,
+        stratum_retention_policy=retention_policy,
+    )
+
+    for __ in range(100):
+        c1.DepositStratum()
+        assert [*c1.IterRankDifferentiaZip()] == [
+            *zip(c1.IterRetainedRanks(), c1.IterRetainedDifferentia())
+        ]
+        iter_ = c1.IterRankDifferentiaZip(copyable=True)
+        iter_copy = copy(iter_)
+        next(iter_copy)
+        assert [*iter_copy] == [
+            *zip(c1.IterRetainedRanks(), c1.IterRetainedDifferentia())
+        ][1:]
+        assert [*iter_] == [
+            *zip(c1.IterRetainedRanks(), c1.IterRetainedDifferentia())
+        ]
+
+
 def test_CloneNthDescendant_zero():
     column = hstrat.HereditaryStratigraphicColumn()
     assert column.GetNumStrataDeposited() == 1
