@@ -7,6 +7,59 @@ import pytest
 from hstrat import hstrat
 
 
+@pytest.mark.parametrize(
+    "retention_policy",
+    [
+        hstrat.perfect_resolution_algo.Policy(),
+        hstrat.nominal_resolution_algo.Policy(),
+        hstrat.fixed_resolution_algo.Policy(fixed_resolution=10),
+        hstrat.recency_proportional_resolution_algo.Policy(
+            recency_proportional_resolution=2
+        ),
+    ],
+)
+@pytest.mark.parametrize(
+    "differentia_width",
+    [1, 2, 8, 64],
+)
+def test_CalcRankOfFirstRetainedDisparityBetween_specimen(
+    retention_policy, differentia_width
+):
+    column = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=retention_policy,
+        stratum_differentia_bit_width=differentia_width,
+    )
+    column2 = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=retention_policy,
+        stratum_differentia_bit_width=differentia_width,
+    )
+    column.DepositStrata(100)
+
+    child1 = column.CloneDescendant()
+    child2 = column.CloneDescendant()
+
+    assert hstrat.calc_rank_of_first_retained_disparity_between(
+        hstrat.col_to_specimen(column), hstrat.col_to_specimen(column)
+    ) == hstrat.calc_rank_of_first_retained_disparity_between(column, column)
+
+    assert hstrat.calc_rank_of_first_retained_disparity_between(
+        hstrat.col_to_specimen(column), hstrat.col_to_specimen(column2)
+    ) == hstrat.calc_rank_of_first_retained_disparity_between(column, column2)
+
+    assert hstrat.calc_rank_of_first_retained_disparity_between(
+        hstrat.col_to_specimen(column), hstrat.col_to_specimen(child1)
+    ) == hstrat.calc_rank_of_first_retained_disparity_between(column, child1)
+
+    assert hstrat.calc_rank_of_first_retained_disparity_between(
+        hstrat.col_to_specimen(child1), hstrat.col_to_specimen(child2)
+    ) == hstrat.calc_rank_of_first_retained_disparity_between(child1, child2)
+
+    child1.DepositStrata(10)
+    assert hstrat.calc_rank_of_first_retained_disparity_between(
+        hstrat.col_to_specimen(child1), hstrat.col_to_specimen(child2)
+    ) == hstrat.calc_rank_of_first_retained_disparity_between(child1, child2)
+
+
 @pytest.mark.parametrize(
     "retention_policy",
     [
@@ -26,7 +79,7 @@ from hstrat import hstrat
         ),
     ],
 )
-def test_comparison_commutativity_asyncrhonous(
+def test_comparison_commutativity_asynchronous(
     retention_policy,
     ordered_store,
 ):
@@ -38,7 +91,8 @@ def test_comparison_commutativity_asyncrhonous(
         for __ in range(10)
     ]
 
-    for generation in range(100):
+    for _generation in range(100):
+        _ = _generation
         for first, second in it.combinations(population, 2):
             # assert commutativity
             assert hstrat.calc_rank_of_first_retained_disparity_between(
@@ -84,7 +138,7 @@ def test_comparison_commutativity_asyncrhonous(
         ),
     ],
 )
-def test_comparison_commutativity_syncrhonous(
+def test_comparison_commutativity_synchronous(
     retention_policy,
     ordered_store,
 ):
@@ -97,8 +151,8 @@ def test_comparison_commutativity_syncrhonous(
         for __ in range(10)
     ]
 
-    for generation in range(100):
-
+    for _generation in range(100):
+        _ = _generation
         for first, second in it.combinations(population, 2):
             # assert commutativity
             assert hstrat.calc_rank_of_first_retained_disparity_between(
@@ -161,7 +215,9 @@ def test_comparison_validity(retention_policy, ordered_store):
             if fdrw is not None:
                 assert 0 <= fdrw <= generation
 
-            assert hstrat.calc_rank_of_mrca_bounds_between(first, second) in [
+            assert hstrat.calc_rank_of_mrca_bounds_between(
+                first, second, prior="arbitrary"
+            ) in [
                 (lcrw, opyt.or_value(fdrw, first.GetNumStrataDeposited())),
                 None,
             ]
@@ -215,7 +271,8 @@ def test_scenario_no_mrca(
         stratum_retention_policy=retention_policy2,
     )
 
-    for generation in range(100):
+    for _generation in range(100):
+        _ = _generation
         assert (
             hstrat.calc_rank_of_first_retained_disparity_between(first, second)
             == 0
@@ -224,7 +281,6 @@ def test_scenario_no_mrca(
             hstrat.calc_rank_of_first_retained_disparity_between(first, second)
             == 0
         )
-
         first.DepositStratum()
         second.DepositStratum()
 
@@ -251,13 +307,56 @@ def test_scenario_no_divergence(retention_policy, ordered_store):
         stratum_retention_policy=retention_policy,
     )
 
-    for generation in range(100):
+    for _generation in range(100):
+        _ = _generation
         assert (
             hstrat.calc_rank_of_first_retained_disparity_between(
                 column, column
             )
             is None
         )
+        column.DepositStratum()
+
+
+@pytest.mark.parametrize(
+    "retention_policy",
+    [
+        hstrat.perfect_resolution_algo.Policy(),
+        hstrat.nominal_resolution_algo.Policy(),
+        hstrat.fixed_resolution_algo.Policy(fixed_resolution=10),
+        hstrat.recency_proportional_resolution_algo.Policy(
+            recency_proportional_resolution=2,
+        ),
+        hstrat.recency_proportional_resolution_algo.Policy(
+            recency_proportional_resolution=10,
+        ),
+    ],
+)
+@pytest.mark.parametrize(
+    "ordered_store",
+    [
+        hstrat.HereditaryStratumOrderedStoreDict,
+        hstrat.HereditaryStratumOrderedStoreList,
+        hstrat.HereditaryStratumOrderedStoreTree,
+    ],
+)
+def test_scenario_single_branch_divergence(retention_policy, ordered_store):
+    column = hstrat.HereditaryStratigraphicColumn(
+        stratum_ordered_store=ordered_store,
+        stratum_retention_policy=retention_policy,
+    )
+
+    for generation in range(40):
+        branch_column = column.CloneDescendant()
+        for _branch_generation in range(40):
+            _ = _branch_generation
+            assert (
+                hstrat.calc_rank_of_first_retained_disparity_between(
+                    column, branch_column
+                )
+                == generation + 1
+            )
+            branch_column.DepositStratum()
 
         column.DepositStratum()
 
@@ -267,6 +366,9 @@ def test_scenario_no_divergence(retention_policy, ordered_store):
     [
         hstrat.perfect_resolution_algo.Policy(),
         hstrat.nominal_resolution_algo.Policy(),
+        hstrat.recency_proportional_resolution_algo.Policy(
+            recency_proportional_resolution=2,
+        ),
         hstrat.fixed_resolution_algo.Policy(fixed_resolution=10),
     ],
 )
@@ -284,8 +386,7 @@ def test_scenario_partial_even_divergence(retention_policy, ordered_store):
         stratum_retention_policy=retention_policy,
     )
 
-    for generation in range(100):
-        first.DepositStratum()
+    first.DepositStrata(100)
 
     second = first.Clone()
 
@@ -330,8 +431,7 @@ def test_scenario_partial_uneven_divergence(retention_policy, ordered_store):
         stratum_retention_policy=retention_policy,
     )
 
-    for generation in range(100):
-        first.DepositStratum()
+    first.DepositStrata(100)
 
     second = first.Clone()
 
@@ -381,8 +481,7 @@ def test_CalcRankOfFirstRetainedDisparityWith1(
         stratum_ordered_store=ordered_store,
     )
 
-    for generation in range(100):
-        column.DepositStratum()
+    column.DepositStrata(100)
 
     offspring1 = column.CloneDescendant()
     offspring2 = column.CloneDescendant()
@@ -491,9 +590,8 @@ def test_CalcRankOfFirstRetainedDisparityWith1(
                 is None
             )
 
-    for generation in range(100):
-        offspring1.DepositStratum()
-        offspring2.DepositStratum()
+    offspring1.DepositStrata(100)
+    offspring2.DepositStrata(100)
 
     for c1, c2 in it.combinations([column, offspring1, offspring2], 2):
         if differentia_width == 64:
@@ -734,15 +832,13 @@ def test_CalcRankOfFirstRetainedDisparityWith3(ordered_store):
         stratum_retention_policy=hstrat.nominal_resolution_algo.Policy(),
     )
 
-    for generation in range(100):
-        column.DepositStratum()
+    column.DepositStrata(100)
 
     offspring1 = column.CloneDescendant()
     offspring2 = column.CloneDescendant()
 
-    for generation in range(100):
-        offspring1.DepositStratum()
-        offspring2.DepositStratum()
+    offspring1.DepositStrata(100)
+    offspring2.DepositStrata(100)
 
     for c2 in [offspring1, offspring2]:
         assert (
@@ -913,8 +1009,7 @@ def test_CalcRankOfFirstRetainedDisparityWith5(
         stratum_retention_policy=hstrat.fixed_resolution_algo.Policy(2),
     )
 
-    for generation in range(100):
-        column.DepositStratum()
+    column.DepositStrata(100)
 
     offspring1 = column.CloneDescendant()
     offspring2 = column.CloneDescendant()
@@ -982,9 +1077,8 @@ def test_CalcRankOfFirstRetainedDisparityWith5(
                     c, c, conf
                 ) == c.GetRankAtColumnIndex(col_idx)
 
-    for generation in range(99):
-        offspring1.DepositStratum()
-        offspring2.DepositStratum()
+    offspring1.DepositStrata(99)
+    offspring2.DepositStrata(99)
 
     for c1, c2 in it.combinations([column, offspring1, offspring2], 2):
         if differentia_width == 64:
@@ -1035,3 +1129,42 @@ def test_CalcRankOfFirstRetainedDisparityWith5(
                 assert hstrat.calc_rank_of_first_retained_disparity_between(
                     c, c, conf
                 ) == c.GetRankAtColumnIndex(col_idx)
+
+
+@pytest.mark.parametrize(
+    "differentia_width",
+    [1, 8, 64],
+)
+@pytest.mark.parametrize(
+    "policy",
+    [
+        hstrat.fixed_resolution_algo.Policy(3),
+        hstrat.recency_proportional_resolution_algo.Policy(1),
+        hstrat.nominal_resolution_algo.Policy(),
+        hstrat.perfect_resolution_algo.Policy(),
+    ],
+)
+def test_artifact_types_equiv(differentia_width, policy):
+    common_ancestor = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=policy,
+        stratum_differentia_bit_width=differentia_width,
+    ).CloneNthDescendant(7)
+    c1 = common_ancestor.CloneNthDescendant(4)
+    c2 = common_ancestor.CloneNthDescendant(9)
+    c_x = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=policy,
+        stratum_differentia_bit_width=differentia_width,
+    ).CloneNthDescendant(7)
+    c_y = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=policy,
+        stratum_differentia_bit_width=differentia_width,
+    )
+
+    for a, b in it.product(
+        [common_ancestor, c1, c2, c_x, c_y],
+        [common_ancestor, c1, c2, c_x, c_y],
+    ):
+        assert hstrat.calc_rank_of_first_retained_disparity_between(
+            hstrat.col_to_specimen(a),
+            hstrat.col_to_specimen(b),
+        ) == hstrat.calc_rank_of_first_retained_disparity_between(a, b)
