@@ -13,6 +13,62 @@ from hstrat import hstrat
         hstrat.perfect_resolution_algo.Policy(),
         hstrat.nominal_resolution_algo.Policy(),
         hstrat.fixed_resolution_algo.Policy(fixed_resolution=10),
+        hstrat.recency_proportional_resolution_algo.Policy(
+            recency_proportional_resolution=2
+        ),
+    ],
+)
+@pytest.mark.parametrize(
+    "differentia_width",
+    [1, 2, 8, 64],
+)
+def test_CalcRankOfLastRetainedCommonalityBetween_specimen(
+    retention_policy, differentia_width
+):
+    column = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=retention_policy,
+        stratum_differentia_bit_width=differentia_width,
+    )
+    column2 = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=retention_policy,
+        stratum_differentia_bit_width=differentia_width,
+    )
+    column.DepositStrata(100)
+
+    child1 = column.CloneDescendant()
+    child2 = column.CloneDescendant()
+
+    assert hstrat.calc_rank_of_last_retained_commonality_between(
+        hstrat.col_to_specimen(column), hstrat.col_to_specimen(column2)
+    ) == hstrat.calc_rank_of_last_retained_commonality_between(column, column2)
+
+    assert hstrat.calc_rank_of_last_retained_commonality_between(
+        hstrat.col_to_specimen(column), hstrat.col_to_specimen(column)
+    ) == hstrat.calc_rank_of_last_retained_commonality_between(column, column)
+
+    assert hstrat.calc_rank_of_last_retained_commonality_between(
+        hstrat.col_to_specimen(column), hstrat.col_to_specimen(child1)
+    ) == hstrat.calc_rank_of_last_retained_commonality_between(column, child1)
+
+    assert hstrat.calc_rank_of_last_retained_commonality_between(
+        hstrat.col_to_specimen(child1), hstrat.col_to_specimen(child2)
+    ) == hstrat.calc_rank_of_last_retained_commonality_between(child1, child2)
+
+    child1.DepositStrata(10)
+    assert hstrat.calc_rank_of_last_retained_commonality_between(
+        hstrat.col_to_specimen(child1), hstrat.col_to_specimen(child2)
+    ) == hstrat.calc_rank_of_last_retained_commonality_between(child1, child2)
+
+
+@pytest.mark.parametrize(
+    "retention_policy",
+    [
+        hstrat.perfect_resolution_algo.Policy(),
+        hstrat.nominal_resolution_algo.Policy(),
+        hstrat.fixed_resolution_algo.Policy(fixed_resolution=10),
+        hstrat.recency_proportional_resolution_algo.Policy(
+            recency_proportional_resolution=2
+        ),
     ],
 )
 @pytest.mark.parametrize(
@@ -26,7 +82,7 @@ from hstrat import hstrat
         ),
     ],
 )
-def test_comparison_commutativity_asyncrhonous(
+def test_comparison_commutativity_asynchronous(
     retention_policy,
     ordered_store,
 ):
@@ -38,7 +94,8 @@ def test_comparison_commutativity_asyncrhonous(
         for __ in range(10)
     ]
 
-    for generation in range(100):
+    for _generation in range(100):
+        _ = _generation
         for first, second in it.combinations(population, 2):
             # assert commutativity
             assert hstrat.calc_rank_of_last_retained_commonality_between(
@@ -66,6 +123,9 @@ def test_comparison_commutativity_asyncrhonous(
         ),
         hstrat.nominal_resolution_algo.Policy(),
         hstrat.fixed_resolution_algo.Policy(fixed_resolution=10),
+        hstrat.recency_proportional_resolution_algo.Policy(
+            recency_proportional_resolution=2
+        ),
     ],
 )
 @pytest.mark.parametrize(
@@ -82,7 +142,7 @@ def test_comparison_commutativity_asyncrhonous(
         ),
     ],
 )
-def test_comparison_commutativity_syncrhonous(
+def test_comparison_commutativity_synchronous(
     retention_policy,
     ordered_store,
 ):
@@ -95,8 +155,8 @@ def test_comparison_commutativity_syncrhonous(
         for __ in range(10)
     ]
 
-    for generation in range(100):
-
+    for _generation in range(100):
+        _ = _generation
         for first, second in it.combinations(population, 2):
             # assert commutativity
             assert hstrat.calc_rank_of_last_retained_commonality_between(
@@ -120,6 +180,9 @@ def test_comparison_commutativity_syncrhonous(
         hstrat.perfect_resolution_algo.Policy(),
         hstrat.nominal_resolution_algo.Policy(),
         hstrat.fixed_resolution_algo.Policy(fixed_resolution=10),
+        hstrat.recency_proportional_resolution_algo.Policy(
+            recency_proportional_resolution=2
+        ),
     ],
 )
 @pytest.mark.parametrize(
@@ -156,7 +219,9 @@ def test_comparison_validity(retention_policy, ordered_store):
             if fdrw is not None:
                 assert 0 <= fdrw <= generation
 
-            assert hstrat.calc_rank_of_mrca_bounds_between(first, second) in [
+            assert hstrat.calc_rank_of_mrca_bounds_between(
+                first, second, prior="arbitrary"
+            ) in [
                 (lcrw, opyt.or_value(fdrw, first.GetNumStrataDeposited())),
                 None,
             ]
@@ -178,6 +243,9 @@ def test_comparison_validity(retention_policy, ordered_store):
         hstrat.perfect_resolution_algo.Policy(),
         hstrat.nominal_resolution_algo.Policy(),
         hstrat.fixed_resolution_algo.Policy(fixed_resolution=10),
+        hstrat.recency_proportional_resolution_algo.Policy(
+            recency_proportional_resolution=2
+        ),
     ],
 )
 @pytest.mark.parametrize(
@@ -186,6 +254,9 @@ def test_comparison_validity(retention_policy, ordered_store):
         hstrat.perfect_resolution_algo.Policy(),
         hstrat.nominal_resolution_algo.Policy(),
         hstrat.fixed_resolution_algo.Policy(fixed_resolution=10),
+        hstrat.recency_proportional_resolution_algo.Policy(
+            recency_proportional_resolution=2
+        ),
     ],
 )
 @pytest.mark.parametrize(
@@ -210,7 +281,8 @@ def test_scenario_no_mrca(
         stratum_retention_policy=retention_policy2,
     )
 
-    for generation in range(100):
+    for _generation in range(100):
+        _ = _generation
         assert (
             hstrat.calc_rank_of_last_retained_commonality_between(
                 first, second
@@ -234,6 +306,9 @@ def test_scenario_no_mrca(
         hstrat.perfect_resolution_algo.Policy(),
         hstrat.nominal_resolution_algo.Policy(),
         hstrat.fixed_resolution_algo.Policy(fixed_resolution=10),
+        hstrat.recency_proportional_resolution_algo.Policy(
+            recency_proportional_resolution=2
+        ),
     ],
 )
 @pytest.mark.parametrize(
@@ -267,6 +342,50 @@ def test_scenario_no_divergence(retention_policy, ordered_store):
         hstrat.perfect_resolution_algo.Policy(),
         hstrat.nominal_resolution_algo.Policy(),
         hstrat.fixed_resolution_algo.Policy(fixed_resolution=10),
+        hstrat.recency_proportional_resolution_algo.Policy(
+            recency_proportional_resolution=2
+        ),
+    ],
+)
+@pytest.mark.parametrize(
+    "ordered_store",
+    [
+        hstrat.HereditaryStratumOrderedStoreDict,
+        hstrat.HereditaryStratumOrderedStoreList,
+        hstrat.HereditaryStratumOrderedStoreTree,
+    ],
+)
+def test_scenario_single_branch_divergence(retention_policy, ordered_store):
+    column = hstrat.HereditaryStratigraphicColumn(
+        stratum_ordered_store=ordered_store,
+        stratum_retention_policy=retention_policy,
+    )
+
+    for generation in range(25):
+        branch_column = column.CloneDescendant()
+        for _branch_generation in range(25):
+            _ = _branch_generation
+            assert (
+                0
+                <= hstrat.calc_rank_of_last_retained_commonality_between(
+                    column, branch_column
+                )
+                <= generation
+            )
+            branch_column.DepositStratum()
+
+        column.DepositStratum()
+
+
+@pytest.mark.parametrize(
+    "retention_policy",
+    [
+        hstrat.perfect_resolution_algo.Policy(),
+        hstrat.nominal_resolution_algo.Policy(),
+        hstrat.fixed_resolution_algo.Policy(fixed_resolution=10),
+        hstrat.recency_proportional_resolution_algo.Policy(
+            recency_proportional_resolution=2
+        ),
     ],
 )
 @pytest.mark.parametrize(
@@ -283,15 +402,15 @@ def test_scenario_partial_even_divergence(retention_policy, ordered_store):
         stratum_retention_policy=retention_policy,
     )
 
-    for generation in range(100):
-        first.DepositStratum()
+    first.DepositStrata(100)
 
     second = first.Clone()
 
     first.DepositStratum()
     second.DepositStratum()
 
-    for generation in range(101, 200):
+    for _generation in range(101, 200):
+        _ = _generation
         assert (
             0
             <= hstrat.calc_rank_of_last_retained_commonality_between(
@@ -310,6 +429,9 @@ def test_scenario_partial_even_divergence(retention_policy, ordered_store):
         hstrat.perfect_resolution_algo.Policy(),
         hstrat.nominal_resolution_algo.Policy(),
         hstrat.fixed_resolution_algo.Policy(fixed_resolution=10),
+        hstrat.recency_proportional_resolution_algo.Policy(
+            recency_proportional_resolution=2
+        ),
     ],
 )
 @pytest.mark.parametrize(
@@ -329,14 +451,14 @@ def test_scenario_partial_uneven_divergence(retention_policy, ordered_store):
         stratum_retention_policy=retention_policy,
     )
 
-    for generation in range(100):
-        first.DepositStratum()
+    first.DepositStrata(100)
 
     second = first.Clone()
 
     first.DepositStratum()
 
-    for generation in range(101, 200):
+    for _generation in range(101, 200):
+        _ = _generation
         assert (
             0
             <= hstrat.calc_rank_of_last_retained_commonality_between(
@@ -344,12 +466,12 @@ def test_scenario_partial_uneven_divergence(retention_policy, ordered_store):
             )
             <= 100
         )
-
         first.DepositStratum()
 
     second.DepositStratum()
 
-    for generation in range(101, 200):
+    for _generation in range(101, 200):
+        _ = _generation
         assert (
             0
             <= hstrat.calc_rank_of_last_retained_commonality_between(
@@ -357,7 +479,6 @@ def test_scenario_partial_uneven_divergence(retention_policy, ordered_store):
             )
             <= 100
         )
-
         second.DepositStratum()
 
 
@@ -367,6 +488,9 @@ def test_scenario_partial_uneven_divergence(retention_policy, ordered_store):
         hstrat.perfect_resolution_algo.Policy(),
         hstrat.nominal_resolution_algo.Policy(),
         hstrat.fixed_resolution_algo.Policy(fixed_resolution=10),
+        hstrat.recency_proportional_resolution_algo.Policy(
+            recency_proportional_resolution=2
+        ),
     ],
 )
 @pytest.mark.parametrize(
@@ -382,8 +506,7 @@ def _do_test_CalcRankOfLastRetainedCommonalityWith1(
         stratum_ordered_store=ordered_store,
     )
 
-    for generation in range(100):
-        column.DepositStratum()
+    column.DepositStrata(100)
 
     offspring1 = column.CloneDescendant()
     offspring2 = column.CloneDescendant()
@@ -432,9 +555,8 @@ def _do_test_CalcRankOfLastRetainedCommonalityWith1(
             significance_level=0.01,
         )
 
-    for generation in range(100):
-        offspring1.DepositStratum()
-        offspring2.DepositStratum()
+    offspring1.DepositStrata(100)
+    offspring2.DepositStrata(100)
 
     for c1, c2 in it.combinations([column, offspring1, offspring2], 2):
         if differentia_width == 64:
@@ -562,15 +684,13 @@ def test_CalcRankOfLastRetainedCommonalityWith3(ordered_store):
         stratum_retention_policy=hstrat.nominal_resolution_algo.Policy(),
     )
 
-    for generation in range(100):
-        column.DepositStratum()
+    column.DepositStrata(100)
 
     offspring1 = column.CloneDescendant()
     offspring2 = column.CloneDescendant()
 
-    for generation in range(100):
-        offspring1.DepositStratum()
-        offspring2.DepositStratum()
+    offspring1.DepositStrata(100)
+    offspring2.DepositStrata(100)
 
     for c1, c2 in it.combinations([column, offspring1, offspring2], 2):
         assert c1.GetNumStrataRetained() == 2
@@ -692,8 +812,7 @@ def test_CalcRankOfLastRetainedCommonalityWith5(
         stratum_retention_policy=hstrat.fixed_resolution_algo.Policy(2),
     )
 
-    for generation in range(100):
-        column.DepositStratum()
+    column.DepositStrata(100)
 
     offspring1 = column.CloneDescendant()
     offspring2 = column.CloneDescendant()
@@ -746,9 +865,8 @@ def test_CalcRankOfLastRetainedCommonalityWith5(
                 c, c, conf
             ) == c.GetRankAtColumnIndex(col_idx)
 
-    for generation in range(99):
-        offspring1.DepositStratum()
-        offspring2.DepositStratum()
+    offspring1.DepositStrata(99)
+    offspring2.DepositStrata(99)
 
     for c1, c2 in it.combinations([column, offspring1, offspring2], 2):
         if differentia_width == 64:
@@ -784,3 +902,42 @@ def test_CalcRankOfLastRetainedCommonalityWith5(
             assert hstrat.calc_rank_of_last_retained_commonality_between(
                 c, c, conf
             ) == c.GetRankAtColumnIndex(col_idx)
+
+
+@pytest.mark.parametrize(
+    "differentia_width",
+    [1, 8, 64],
+)
+@pytest.mark.parametrize(
+    "policy",
+    [
+        hstrat.fixed_resolution_algo.Policy(3),
+        hstrat.recency_proportional_resolution_algo.Policy(1),
+        hstrat.nominal_resolution_algo.Policy(),
+        hstrat.perfect_resolution_algo.Policy(),
+    ],
+)
+def test_artifact_types_equiv(differentia_width, policy):
+    common_ancestor = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=policy,
+        stratum_differentia_bit_width=differentia_width,
+    ).CloneNthDescendant(7)
+    c1 = common_ancestor.CloneNthDescendant(4)
+    c2 = common_ancestor.CloneNthDescendant(9)
+    c_x = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=policy,
+        stratum_differentia_bit_width=differentia_width,
+    ).CloneNthDescendant(7)
+    c_y = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=policy,
+        stratum_differentia_bit_width=differentia_width,
+    )
+
+    for a, b in it.product(
+        [common_ancestor, c1, c2, c_x, c_y],
+        [common_ancestor, c1, c2, c_x, c_y],
+    ):
+        assert hstrat.calc_rank_of_last_retained_commonality_between(
+            hstrat.col_to_specimen(a),
+            hstrat.col_to_specimen(b),
+        ) == hstrat.calc_rank_of_last_retained_commonality_between(a, b)
