@@ -7,6 +7,59 @@ import pytest
 from hstrat import hstrat
 
 
+@pytest.mark.parametrize(
+    "retention_policy",
+    [
+        hstrat.perfect_resolution_algo.Policy(),
+        hstrat.nominal_resolution_algo.Policy(),
+        hstrat.fixed_resolution_algo.Policy(fixed_resolution=10),
+        hstrat.recency_proportional_resolution_algo.Policy(
+            recency_proportional_resolution=2
+        ),
+    ],
+)
+@pytest.mark.parametrize(
+    "differentia_width",
+    [1, 2, 8, 64],
+)
+def test_CalcRanksSinceFirstRetainedDisparityWith_specimen(
+    retention_policy, differentia_width
+):
+    column = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=retention_policy,
+        stratum_differentia_bit_width=differentia_width,
+    )
+    column2 = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=retention_policy,
+        stratum_differentia_bit_width=differentia_width,
+    )
+    column.DepositStrata(100)
+
+    child1 = column.CloneDescendant()
+    child2 = column.CloneDescendant()
+
+    assert hstrat.calc_ranks_since_first_retained_disparity_with(
+        hstrat.col_to_specimen(column), hstrat.col_to_specimen(column2)
+    ) == hstrat.calc_ranks_since_first_retained_disparity_with(column, column2)
+
+    assert hstrat.calc_ranks_since_first_retained_disparity_with(
+        hstrat.col_to_specimen(column), hstrat.col_to_specimen(column)
+    ) == hstrat.calc_ranks_since_first_retained_disparity_with(column, column)
+
+    assert hstrat.calc_ranks_since_first_retained_disparity_with(
+        hstrat.col_to_specimen(column), hstrat.col_to_specimen(child1)
+    ) == hstrat.calc_ranks_since_first_retained_disparity_with(column, child1)
+
+    assert hstrat.calc_ranks_since_first_retained_disparity_with(
+        hstrat.col_to_specimen(child1), hstrat.col_to_specimen(child2)
+    ) == hstrat.calc_ranks_since_first_retained_disparity_with(child1, child2)
+
+    child1.DepositStrata(10)
+    assert hstrat.calc_ranks_since_first_retained_disparity_with(
+        hstrat.col_to_specimen(child1), hstrat.col_to_specimen(child2)
+    ) == hstrat.calc_ranks_since_first_retained_disparity_with(child1, child2)
+
+
 @pytest.mark.parametrize(
     "retention_policy",
     [
@@ -32,7 +85,7 @@ from hstrat import hstrat
         ),
     ],
 )
-def test_comparison_commutativity_syncrhonous(
+def test_comparison_commutativity_synchronous(
     retention_policy,
     ordered_store,
 ):
@@ -45,8 +98,8 @@ def test_comparison_commutativity_syncrhonous(
         for __ in range(10)
     ]
 
-    for generation in range(100):
-
+    for _generation in range(100):
+        _ = _generation
         for first, second in it.combinations(population, 2):
             # assert commutativity
             assert hstrat.calc_ranks_since_first_retained_disparity_with(
@@ -107,9 +160,13 @@ def test_comparison_validity(retention_policy, ordered_store):
                 assert -1 <= rsfdw <= generation
 
             assert hstrat.calc_ranks_since_mrca_bounds_with(
-                first, second
+                first,
+                second,
+                prior="arbitrary",
             ) is None or hstrat.calc_ranks_since_mrca_bounds_with(
-                first, second
+                first,
+                second,
+                prior="arbitrary",
             ) == (
                 opyt.or_value(rsfdw, -1) + 1,
                 rslcw + 1,
@@ -204,14 +261,14 @@ def test_scenario_no_divergence(retention_policy, ordered_store):
         stratum_retention_policy=retention_policy,
     )
 
-    for generation in range(100):
+    for _generation in range(100):
+        _ = _generation
         assert (
             hstrat.calc_ranks_since_first_retained_disparity_with(
                 column, column
             )
             is None
         )
-
         column.DepositStratum()
 
 
@@ -237,8 +294,7 @@ def test_scenario_partial_even_divergence(retention_policy, ordered_store):
         stratum_retention_policy=retention_policy,
     )
 
-    for generation in range(100):
-        first.DepositStratum()
+    first.DepositStrata(100)
 
     second = first.Clone()
 
@@ -283,8 +339,7 @@ def test_scenario_partial_uneven_divergence(retention_policy, ordered_store):
         stratum_retention_policy=retention_policy,
     )
 
-    for generation in range(100):
-        first.DepositStratum()
+    first.DepositStrata(100)
 
     second = first.Clone()
 
@@ -334,8 +389,7 @@ def test_CalcRanksSinceFirstRetainedDisparityWith1(differentia_width):
         stratum_differentia_bit_width=differentia_width,
     )
 
-    for generation in range(100):
-        column.DepositStratum()
+    column.DepositStrata(100)
 
     offspring1 = column.CloneDescendant()
     offspring2 = column.CloneDescendant()
@@ -441,9 +495,8 @@ def test_CalcRanksSinceFirstRetainedDisparityWith1(differentia_width):
                 ),
             )
 
-    for generation in range(100):
-        offspring1.DepositStratum()
-        offspring2.DepositStratum()
+    offspring1.DepositStrata(100)
+    offspring2.DepositStrata(100)
 
     for c1, c2 in it.combinations([column, offspring1, offspring2], 2):
         if differentia_width == 64:
@@ -532,3 +585,43 @@ def test_CalcRanksSinceFirstRetainedDisparityWith1(differentia_width):
                     significance_level=0.01,
                 ),
             )
+
+
+@pytest.mark.parametrize(
+    "differentia_width",
+    # [1, 8, 64],
+    [64],
+)
+@pytest.mark.parametrize(
+    "policy",
+    [
+        hstrat.fixed_resolution_algo.Policy(3),
+        # hstrat.recency_proportional_resolution_algo.Policy(1),
+        # hstrat.nominal_resolution_algo.Policy(),
+        # hstrat.perfect_resolution_algo.Policy(),
+    ],
+)
+def test_artifact_types_equiv(differentia_width, policy):
+    common_ancestor = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=policy,
+        stratum_differentia_bit_width=differentia_width,
+    ).CloneNthDescendant(7)
+    c1 = common_ancestor.CloneNthDescendant(4)
+    c2 = common_ancestor.CloneNthDescendant(9)
+    c_x = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=policy,
+        stratum_differentia_bit_width=differentia_width,
+    ).CloneNthDescendant(7)
+    c_y = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=policy,
+        stratum_differentia_bit_width=differentia_width,
+    )
+
+    for a, b in it.product(
+        [common_ancestor, c1, c2, c_x, c_y],
+        [common_ancestor, c1, c2, c_x, c_y],
+    ):
+        assert hstrat.calc_ranks_since_first_retained_disparity_with(
+            hstrat.col_to_specimen(a),
+            hstrat.col_to_specimen(b),
+        ) == hstrat.calc_ranks_since_first_retained_disparity_with(a, b)
