@@ -9,6 +9,88 @@ from scipy import stats
 from hstrat import hstrat
 
 
+@pytest.mark.parametrize(
+    "retention_policy",
+    [
+        hstrat.perfect_resolution_algo.Policy(),
+        hstrat.nominal_resolution_algo.Policy(),
+        hstrat.fixed_resolution_algo.Policy(fixed_resolution=10),
+        hstrat.recency_proportional_resolution_algo.Policy(
+            recency_proportional_resolution=2
+        ),
+    ],
+)
+@pytest.mark.parametrize(
+    "differentia_width",
+    [1, 2, 8, 64],
+)
+@pytest.mark.parametrize(
+    "confidence_level",
+    [0.95, 0.88],
+)
+def test_calc_rank_of_mrca_bounds_between_specimen(
+    retention_policy, differentia_width, confidence_level
+):
+    column = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=retention_policy,
+        stratum_differentia_bit_width=differentia_width,
+    )
+    column2 = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=retention_policy,
+        stratum_differentia_bit_width=differentia_width,
+    )
+    column.DepositStrata(100)
+
+    child1 = column.CloneDescendant()
+    child2 = column.CloneDescendant()
+
+    assert hstrat.calc_rank_of_mrca_bounds_between(
+        hstrat.col_to_specimen(column),
+        hstrat.col_to_specimen(column2),
+        prior="arbitrary",
+        confidence_level=confidence_level,
+    ) == hstrat.calc_rank_of_mrca_bounds_between(
+        column, column2, prior="arbitrary", confidence_level=confidence_level
+    )
+
+    assert hstrat.calc_rank_of_mrca_bounds_between(
+        hstrat.col_to_specimen(column),
+        hstrat.col_to_specimen(column),
+        prior="arbitrary",
+        confidence_level=confidence_level,
+    ) == hstrat.calc_rank_of_mrca_bounds_between(
+        column, column, prior="arbitrary", confidence_level=confidence_level
+    )
+
+    assert hstrat.calc_rank_of_mrca_bounds_between(
+        hstrat.col_to_specimen(column),
+        hstrat.col_to_specimen(child1),
+        prior="arbitrary",
+        confidence_level=confidence_level,
+    ) == hstrat.calc_rank_of_mrca_bounds_between(
+        column, child1, prior="arbitrary", confidence_level=confidence_level
+    )
+
+    assert hstrat.calc_rank_of_mrca_bounds_between(
+        hstrat.col_to_specimen(child1),
+        hstrat.col_to_specimen(child2),
+        prior="arbitrary",
+        confidence_level=confidence_level,
+    ) == hstrat.calc_rank_of_mrca_bounds_between(
+        child1, child2, prior="arbitrary", confidence_level=confidence_level
+    )
+
+    child1.DepositStrata(10)
+    assert hstrat.calc_rank_of_mrca_bounds_between(
+        hstrat.col_to_specimen(child1),
+        hstrat.col_to_specimen(child2),
+        prior="arbitrary",
+        confidence_level=confidence_level,
+    ) == hstrat.calc_rank_of_mrca_bounds_between(
+        child1, child2, prior="arbitrary", confidence_level=confidence_level
+    )
+
+
 @pytest.mark.filterwarnings(
     "ignore:Insufficient common ranks between columns to detect common ancestry at given confidence level."
 )
@@ -31,7 +113,7 @@ from hstrat import hstrat
         ),
     ],
 )
-def test_comparison_commutativity_asyncrhonous(
+def test_comparison_commutativity_asynchronous(
     retention_policy,
     ordered_store,
 ):
@@ -43,12 +125,15 @@ def test_comparison_commutativity_asyncrhonous(
         for __ in range(10)
     ]
 
-    for generation in range(100):
+    for _generation in range(100):
+        _ = _generation
         for first, second in it.combinations(population, 2):
             # assert commutativity
             assert hstrat.calc_rank_of_mrca_bounds_between(
-                first, second
-            ) == hstrat.calc_rank_of_mrca_bounds_between(second, first)
+                first, second, prior="arbitrary"
+            ) == hstrat.calc_rank_of_mrca_bounds_between(
+                second, first, prior="arbitrary"
+            )
 
         # advance generation
         random.shuffle(population)
@@ -106,8 +191,8 @@ def test_CalcRankOfMrcaBoundsWith(retention_policy, ordered_store):
     forked_isolated = column.Clone()
     unrelated_isolated = make_bundle()
 
-    for generation in range(100):
-
+    for _generation in range(100):
+        _ = _generation
         for f, s in it.chain(
             it.combinations(population, 2),
             zip(population, cyclify(forked_isolated)),
@@ -116,7 +201,7 @@ def test_CalcRankOfMrcaBoundsWith(retention_policy, ordered_store):
             zip(cyclify(frozen_copy), population),
         ):
             lb, ub = hstrat.calc_rank_of_mrca_bounds_between(
-                f["test"], s["test"]
+                f["test"], s["test"], prior="arbitrary"
             )
             actual_rank_of_mrca = hstrat.get_last_common_stratum_between(
                 f["control"],
@@ -131,7 +216,9 @@ def test_CalcRankOfMrcaBoundsWith(retention_policy, ordered_store):
             zip(cyclify(unrelated_isolated), population),
         ):
             assert (
-                hstrat.calc_rank_of_mrca_bounds_between(f["test"], s["test"])
+                hstrat.calc_rank_of_mrca_bounds_between(
+                    f["test"], s["test"], prior="arbitrary"
+                )
                 is None
             )
 
@@ -180,7 +267,7 @@ def test_CalcRankOfMrcaBoundsWith(retention_policy, ordered_store):
         ),
     ],
 )
-def test_comparison_commutativity_syncrhonous(
+def test_comparison_commutativity_synchronous(
     retention_policy,
     ordered_store,
 ):
@@ -193,13 +280,15 @@ def test_comparison_commutativity_syncrhonous(
         for __ in range(10)
     ]
 
-    for generation in range(100):
-
+    for _generation in range(100):
+        _ = _generation
         for first, second in it.combinations(population, 2):
             # assert commutativity
             assert hstrat.calc_rank_of_mrca_bounds_between(
-                first, second
-            ) == hstrat.calc_rank_of_mrca_bounds_between(second, first)
+                first, second, prior="arbitrary"
+            ) == hstrat.calc_rank_of_mrca_bounds_between(
+                second, first, prior="arbitrary"
+            )
 
         # advance generation
         random.shuffle(population)
@@ -255,7 +344,9 @@ def test_comparison_validity(retention_policy, ordered_store):
             if fdrw is not None:
                 assert 0 <= fdrw <= generation
 
-            assert hstrat.calc_rank_of_mrca_bounds_between(first, second) in [
+            assert hstrat.calc_rank_of_mrca_bounds_between(
+                first, second, prior="arbitrary"
+            ) in [
                 (lcrw, opyt.or_value(fdrw, first.GetNumStrataDeposited())),
                 None,
             ]
@@ -329,7 +420,10 @@ def test_CalcRankOfMrcaBoundsWith_narrow_shallow(
         for c1, c2 in zip(column1, column2):
             assert (
                 hstrat.calc_rank_of_mrca_bounds_between(
-                    c1, c2, confidence_level=confidence_level
+                    c1,
+                    c2,
+                    prior="arbitrary",
+                    confidence_level=confidence_level,
                 )
                 is None
             )
@@ -337,6 +431,7 @@ def test_CalcRankOfMrcaBoundsWith_narrow_shallow(
                 hstrat.calc_rank_of_mrca_bounds_between(
                     c2,
                     c1,
+                    prior="arbitrary",
                     confidence_level=confidence_level,
                 )
                 is None
@@ -383,9 +478,8 @@ def test_CalcRankOfMrcaBoundsWith_narrow_with_mrca(
         for __ in range(20)
     ]
 
-    for generation in range(mrca_rank):
-        for column in columns:
-            column.DepositStratum()
+    for column in columns:
+        column.DepositStrata(mrca_rank)
 
     steps = (0, 16, 51)
 
@@ -403,15 +497,17 @@ def test_CalcRankOfMrcaBoundsWith_narrow_with_mrca(
         num_outside_bounds = 0
         for c1, c2 in zip(column1, column2):
             assert hstrat.calc_rank_of_mrca_bounds_between(
-                c1, c2, confidence_level=confidence_level
+                c1, c2, prior="arbitrary", confidence_level=confidence_level
             ) == hstrat.calc_rank_of_mrca_bounds_between(
                 c2,
                 c1,
+                prior="arbitrary",
                 confidence_level=confidence_level,
             )
             res = hstrat.calc_rank_of_mrca_bounds_between(
                 c1,
                 c2,
+                prior="arbitrary",
                 confidence_level=confidence_level,
             )
 
@@ -481,9 +577,8 @@ def test_CalcRankOfMrcaBoundsWith_narrow_no_mrca(
 
     columns = [make_column() for __ in range(20)]
 
-    for generation in range(mrca_rank):
-        for column in columns:
-            column.DepositStratum()
+    for column in columns:
+        column.DepositStrata(mrca_rank)
 
     steps = (0, 16, 51)
 
@@ -501,15 +596,17 @@ def test_CalcRankOfMrcaBoundsWith_narrow_no_mrca(
         num_outside_bounds = 0
         for c1, c2 in zip(column1, column2):
             assert hstrat.calc_rank_of_mrca_bounds_between(
-                c1, c2, confidence_level=confidence_level
+                c1, c2, prior="arbitrary", confidence_level=confidence_level
             ) == hstrat.calc_rank_of_mrca_bounds_between(
                 c2,
                 c1,
+                prior="arbitrary",
                 confidence_level=confidence_level,
             )
             res = hstrat.calc_rank_of_mrca_bounds_between(
                 c1,
                 c2,
+                prior="arbitrary",
                 confidence_level=confidence_level,
             )
 
@@ -534,3 +631,96 @@ def test_CalcRankOfMrcaBoundsWith_narrow_no_mrca(
             )
             < 0.999
         )
+
+
+@pytest.mark.filterwarnings(
+    "ignore:Insufficient common ranks between columns to detect common ancestry at given confidence level."
+)
+@pytest.mark.parametrize(
+    "retention_policy",
+    [
+        hstrat.perfect_resolution_algo.Policy(),
+        hstrat.nominal_resolution_algo.Policy(),
+        hstrat.fixed_resolution_algo.Policy(fixed_resolution=10),
+        hstrat.recency_proportional_resolution_algo.Policy(
+            recency_proportional_resolution=2
+        ),
+    ],
+)
+def test_with_HereditaryStratigraphicSpecimens(
+    retention_policy,
+):
+    population = [
+        hstrat.HereditaryStratigraphicColumn(
+            stratum_retention_policy=retention_policy,
+        )
+        for __ in range(10)
+    ]
+
+    for _generation in range(100):
+        _ = _generation
+        for first, second in it.combinations(population, 2):
+            first_ = hstrat.col_to_specimen(first)
+            second_ = hstrat.col_to_specimen(second)
+            # assert commutativity
+            assert hstrat.calc_rank_of_mrca_bounds_between(
+                first, second, prior="arbitrary"
+            ) == hstrat.calc_rank_of_mrca_bounds_between(
+                first_, second_, prior="arbitrary"
+            )
+
+        # advance generation
+        random.shuffle(population)
+        for target in range(5):
+            population[target] = population[-1].CloneDescendant()
+        for individual in population:
+            # asynchronous generations
+            if random.choice([True, False]):
+                individual.DepositStratum()
+
+
+@pytest.mark.filterwarnings(
+    "ignore:Insufficient common ranks between columns to detect common ancestry at given confidence level."
+)
+@pytest.mark.parametrize(
+    "differentia_width",
+    [1, 8, 64],
+)
+@pytest.mark.parametrize(
+    "policy",
+    [
+        hstrat.fixed_resolution_algo.Policy(3),
+        hstrat.recency_proportional_resolution_algo.Policy(1),
+        hstrat.nominal_resolution_algo.Policy(),
+        hstrat.perfect_resolution_algo.Policy(),
+    ],
+)
+@pytest.mark.parametrize(
+    "prior",
+    ["arbitrary"],
+)
+def test_artifact_types_equiv(differentia_width, policy, prior):
+    common_ancestor = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=policy,
+        stratum_differentia_bit_width=differentia_width,
+    ).CloneNthDescendant(7)
+    c1 = common_ancestor.CloneNthDescendant(4)
+    c2 = common_ancestor.CloneNthDescendant(9)
+    c_x = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=policy,
+        stratum_differentia_bit_width=differentia_width,
+    ).CloneNthDescendant(7)
+    c_y = hstrat.HereditaryStratigraphicColumn(
+        stratum_retention_policy=policy,
+        stratum_differentia_bit_width=differentia_width,
+    )
+
+    for a, b in it.product(
+        [common_ancestor, c1, c2, c_x, c_y],
+        [common_ancestor, c1, c2, c_x, c_y],
+    ):
+        assert hstrat.calc_rank_of_mrca_bounds_between(
+            hstrat.col_to_specimen(a),
+            hstrat.col_to_specimen(b),
+            prior,
+        ) == hstrat.calc_rank_of_mrca_bounds_between(a, b, prior)
